==> jc-1.4.0.tar.gz: soot/util/SmallNumberedMap__24ValueIterator.h <==
// class soot.util.SmallNumberedMap$ValueIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9dcc489be3777b02 soot_util_SmallNumberedMap__24SmallNumberedMapIterator
// @dep_class 2bf0c2bd86d39da0 soot_util_SmallNumberedMap__24ValueIterator

// header file dependencies
// @dep_header soot_util_SmallNumberedMap__24SmallNumberedMapIterator

#include "soot/util/SmallNumberedMap__24SmallNumberedMapIterator.h"

#ifndef _JC_soot_util_SmallNumberedMap__24ValueIterator_H_
#define _JC_soot_util_SmallNumberedMap__24ValueIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_SmallNumberedMap$object;

// Typedefs
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs	_jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs	_jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$refs	_jc_soot_util_SmallNumberedMap__24ValueIterator$refs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs	_jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object	_jc_soot_util_SmallNumberedMap__24ValueIterator$object;

typedef const struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods	_jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods;
typedef const struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtable	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtable;
typedef const struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtype	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtype;

// Constructors
extern void _jc_soot_util_SmallNumberedMap__24ValueIterator$method$_init$73a26973a96f859b(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object *, struct _jc_soot_util_SmallNumberedMap$object *, struct _jc_soot_util_SmallNumberedMap$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_SmallNumberedMap__24ValueIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_SmallNumberedMap__24ValueIterator$method_info$next$05874f79a1cf66ea;

// Virtual methods structure
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object *);
};

// Vtable
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods	soot_util_SmallNumberedMap__24ValueIterator;
};

// Vtype
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtype {
	_jc_type			type;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs {
	struct _jc_soot_util_SmallNumberedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$refs {
    _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs	soot_util_SmallNumberedMap__24ValueIterator;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs	soot_util_SmallNumberedMap__24ValueIterator;
};

// Object instance structure
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object {
	_jc_soot_util_SmallNumberedMap__24ValueIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtype	*vtype;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SmallNumberedMap__24ValueIterator$vtype _jc_soot_util_SmallNumberedMap__24ValueIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SmallNumberedMap__24ValueIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SmallNumberedMap__24ValueIterator$class_object;

#endif	/* _JC_soot_util_SmallNumberedMap__24ValueIterator_H_ */

==> jc-1.4.6.tar.gz: soot/util/SmallNumberedMap__24ValueIterator.h <==
// class soot.util.SmallNumberedMap$ValueIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9dcc489be3777b02 soot_util_SmallNumberedMap__24SmallNumberedMapIterator
// @dep_class 2bf0c2bd86d39da0 soot_util_SmallNumberedMap__24ValueIterator

// header file dependencies
// @dep_header soot_util_SmallNumberedMap__24SmallNumberedMapIterator

#include "soot/util/SmallNumberedMap__24SmallNumberedMapIterator.h"

#ifndef _JC_soot_util_SmallNumberedMap__24ValueIterator_H_
#define _JC_soot_util_SmallNumberedMap__24ValueIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_util_SmallNumberedMap$object;

// Typedefs
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs	_jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs	_jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$refs	_jc_soot_util_SmallNumberedMap__24ValueIterator$refs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs	_jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs;
typedef struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object	_jc_soot_util_SmallNumberedMap__24ValueIterator$object;

typedef const struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods	_jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods;
typedef const struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtable	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtable;
typedef const struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtype	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtype;

// Constructors
extern void _jc_soot_util_SmallNumberedMap__24ValueIterator$method$_init$73a26973a96f859b(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object *, struct _jc_soot_util_SmallNumberedMap$object *, struct _jc_soot_util_SmallNumberedMap$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_SmallNumberedMap__24ValueIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_SmallNumberedMap__24ValueIterator$method_info$next$05874f79a1cf66ea;

// Virtual methods structure
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods {
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$vmethods	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$vmethods	soot_util_SmallNumberedMap__24ValueIterator;
};

// Vtype
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$vtype {
	_jc_type			type;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs {
	struct _jc_soot_util_SmallNumberedMap$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$refs {
    _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_refs	soot_util_SmallNumberedMap__24ValueIterator;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_refs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_SmallNumberedMap__24SmallNumberedMapIterator$sub_nonrefs	soot_util_SmallNumberedMap__24SmallNumberedMapIterator;
    _jc_soot_util_SmallNumberedMap__24ValueIterator$sub_nonrefs	soot_util_SmallNumberedMap__24ValueIterator;
};

// Object instance structure
struct _jc_soot_util_SmallNumberedMap__24ValueIterator$object {
	_jc_soot_util_SmallNumberedMap__24ValueIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$vtype	*vtype;
	_jc_soot_util_SmallNumberedMap__24ValueIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_SmallNumberedMap__24ValueIterator$vtype _jc_soot_util_SmallNumberedMap__24ValueIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_SmallNumberedMap__24ValueIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_SmallNumberedMap__24ValueIterator$class_object;

#endif	/* _JC_soot_util_SmallNumberedMap__24ValueIterator_H_ */
